==> jc-1.4.0.tar.gz: java/lang/TypeNotPresentException.h <==
// public class java.lang.TypeNotPresentException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class becf8072ec96cdb4 java_lang_TypeNotPresentException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_TypeNotPresentException_H_
#define _JC_java_lang_TypeNotPresentException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_TypeNotPresentException$sub_refs	_jc_java_lang_TypeNotPresentException$sub_refs;
typedef struct _jc_java_lang_TypeNotPresentException$sub_nonrefs	_jc_java_lang_TypeNotPresentException$sub_nonrefs;
typedef struct _jc_java_lang_TypeNotPresentException$refs	_jc_java_lang_TypeNotPresentException$refs;
typedef struct _jc_java_lang_TypeNotPresentException$nonrefs	_jc_java_lang_TypeNotPresentException$nonrefs;
typedef struct _jc_java_lang_TypeNotPresentException$object	_jc_java_lang_TypeNotPresentException$object;

typedef const struct _jc_java_lang_TypeNotPresentException$vmethods	_jc_java_lang_TypeNotPresentException$vmethods;
typedef const struct _jc_java_lang_TypeNotPresentException$vtable	_jc_java_lang_TypeNotPresentException$vtable;
typedef const struct _jc_java_lang_TypeNotPresentException$vtype	_jc_java_lang_TypeNotPresentException$vtype;

// Constructors
extern void _jc_java_lang_TypeNotPresentException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_lang_TypeNotPresentException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_lang_TypeNotPresentException$method$typeName$93c74ee20480929f(_jc_env *, struct _jc_java_lang_TypeNotPresentException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_TypeNotPresentException$method_info$typeName$93c74ee20480929f;

// Virtual methods structure
struct _jc_java_lang_TypeNotPresentException$vmethods {
	struct _jc_java_lang_String$object	*(*typeName$93c74ee20480929f)(_jc_env *, struct _jc_java_lang_TypeNotPresentException$object *);
};

// Vtable
struct _jc_java_lang_TypeNotPresentException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_TypeNotPresentException$vmethods	java_lang_TypeNotPresentException;
};

// Vtype
struct _jc_java_lang_TypeNotPresentException$vtype {
	_jc_type			type;
	_jc_java_lang_TypeNotPresentException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_TypeNotPresentException$sub_refs {
	struct _jc_java_lang_String$object	*typeName;
};

// Reference instance fields (object)
struct _jc_java_lang_TypeNotPresentException$refs {
    _jc_java_lang_TypeNotPresentException$sub_refs	java_lang_TypeNotPresentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_TypeNotPresentException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_TypeNotPresentException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_TypeNotPresentException$sub_nonrefs	java_lang_TypeNotPresentException;
};

// Object instance structure
struct _jc_java_lang_TypeNotPresentException$object {
	_jc_java_lang_TypeNotPresentException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_TypeNotPresentException$vtype	*vtype;
	_jc_java_lang_TypeNotPresentException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_TypeNotPresentException$vtype _jc_java_lang_TypeNotPresentException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_TypeNotPresentException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_TypeNotPresentException$class_object;

#endif	/* _JC_java_lang_TypeNotPresentException_H_ */

==> jc-1.4.6.tar.gz: java/lang/TypeNotPresentException.h <==
// public class java.lang.TypeNotPresentException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class becf8072ec96cdb4 java_lang_TypeNotPresentException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_TypeNotPresentException_H_
#define _JC_java_lang_TypeNotPresentException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_TypeNotPresentException$sub_refs	_jc_java_lang_TypeNotPresentException$sub_refs;
typedef struct _jc_java_lang_TypeNotPresentException$sub_nonrefs	_jc_java_lang_TypeNotPresentException$sub_nonrefs;
typedef struct _jc_java_lang_TypeNotPresentException$refs	_jc_java_lang_TypeNotPresentException$refs;
typedef struct _jc_java_lang_TypeNotPresentException$nonrefs	_jc_java_lang_TypeNotPresentException$nonrefs;
typedef struct _jc_java_lang_TypeNotPresentException$object	_jc_java_lang_TypeNotPresentException$object;

typedef const struct _jc_java_lang_TypeNotPresentException$vmethods	_jc_java_lang_TypeNotPresentException$vmethods;
typedef const struct _jc_java_lang_TypeNotPresentException$vtable	_jc_java_lang_TypeNotPresentException$vtable;
typedef const struct _jc_java_lang_TypeNotPresentException$vtype	_jc_java_lang_TypeNotPresentException$vtype;

// Constructors
extern void _jc_java_lang_TypeNotPresentException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_lang_TypeNotPresentException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_lang_TypeNotPresentException$method$typeName$93c74ee20480929f(_jc_env *, struct _jc_java_lang_TypeNotPresentException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_TypeNotPresentException$method_info$typeName$93c74ee20480929f;

// Virtual methods structure
struct _jc_java_lang_TypeNotPresentException$vmethods {
	struct _jc_java_lang_String$object	*(*typeName$93c74ee20480929f)(_jc_env *, struct _jc_java_lang_TypeNotPresentException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_TypeNotPresentException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_TypeNotPresentException$vmethods	java_lang_TypeNotPresentException;
};

// Vtype
struct _jc_java_lang_TypeNotPresentException$vtype {
	_jc_type			type;
	_jc_java_lang_TypeNotPresentException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_TypeNotPresentException$sub_refs {
	struct _jc_java_lang_String$object	*typeName;
};

// Reference instance fields (object)
struct _jc_java_lang_TypeNotPresentException$refs {
    _jc_java_lang_TypeNotPresentException$sub_refs	java_lang_TypeNotPresentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_TypeNotPresentException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_TypeNotPresentException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_TypeNotPresentException$sub_nonrefs	java_lang_TypeNotPresentException;
};

// Object instance structure
struct _jc_java_lang_TypeNotPresentException$object {
	_jc_java_lang_TypeNotPresentException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_TypeNotPresentException$vtype	*vtype;
	_jc_java_lang_TypeNotPresentException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_TypeNotPresentException$vtype _jc_java_lang_TypeNotPresentException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_TypeNotPresentException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_TypeNotPresentException$class_object;

#endif	/* _JC_java_lang_TypeNotPresentException_H_ */
